pub struct HttpOrHttpsAcceptor(/* private fields */);
Choose to accept either a HTTP or HTTPS connection

Created by calling the build method on an AcceptorBuilder

Implementations

source

impl HttpOrHttpsAcceptor

source

pub async fn serve<S>(&mut self, service: S)
where S: HttpService<Incoming> + Clone + Send + 'static, S::Future: Send, S::ResBody: Send + 'static, <S::ResBody as Body>::Error: Error + Send + Sync + 'static, <S::ResBody as Body>::Data: Send,

Accepts every connection using the service provided, never completes. Ignores any connection errors produced by the accept method.

source

pub async fn accept<S>( &mut self, service: S ) -> Result<SocketAddr, AcceptorError>
where S: HttpService<Incoming> + Send + 'static, S::Future: Send, S::ResBody: Send + 'static, <S::ResBody as Body>::Error: Error + Send + Sync + 'static, <S::ResBody as Body>::Data: Send,

Accepts a singular connection and spawns it onto the tokio runtime. Returns the address of the connected client.

Errors

If the TCP connection or TLS handshake (HTTPS only) fails