pub struct HyperHttpOrHttpsAcceptor { /* private fields */ }Expand description
Choose to accept either a HTTP or HTTPS connection
Implementations
sourceimpl HyperHttpOrHttpsAcceptor
impl HyperHttpOrHttpsAcceptor
sourcepub const fn new_http(listener: TcpListener) -> Self
pub const fn new_http(listener: TcpListener) -> Self
Create an acceptor that will accept HTTP connections
sourcepub fn new_https(
listener: TcpListener,
tls_acceptor: TlsAcceptor,
handshake_timeout: Duration
) -> Self
pub fn new_https( listener: TcpListener, tls_acceptor: TlsAcceptor, handshake_timeout: Duration ) -> Self
Create an acceptor that will accept HTTPS connections using the provided TlsAcceptor
handshake_timeout is the length of time that should be allowed to finish a TLS handshake before we drop the connection.
Setting it to 0 will not disable the timeout, but will instead instantly drop every connection (you probably don’t want this).